@@ -25,8 +25,9 @@
 #include "babl-base.h"
 
 #include <math.h>
-static inline long
-convert_double_u8_scaled (double        min_val,
+static inline void
+convert_double_u8_scaled (BablConversion *c,
+                          double        min_val,
                           double        max_val,
                           unsigned char min,
                           unsigned char max,
@@ -52,11 +53,11 @@ convert_double_u8_scaled (double        min_val,
       src                   += src_pitch;
       dst                   += dst_pitch;
     }
-  return n;
 }
 
-static inline long
-convert_u8_double_scaled (double        min_val,
+static inline void
+convert_u8_double_scaled (BablConversion *c,
+                          double        min_val,
                           double        max_val,
                           unsigned char min,
                           unsigned char max,
@@ -83,34 +84,33 @@ convert_u8_double_scaled (double        min_val,
       dst += dst_pitch;
       src += src_pitch;
     }
-  return n;
 }
 
 #define MAKE_CONVERSIONS(name, min_val, max_val, min, max)      \
-  static long \
-  convert_ ## name ## _double (void *src, \
+  static void \
+  convert_ ## name ## _double (BablConversion *c, void *src, \
                                void *dst, \
                                int src_pitch, \
                                int dst_pitch, \
                                long n)                               \
   { \
-    return convert_u8_double_scaled (min_val, max_val, min, max, \
-                                     src, dst, src_pitch, dst_pitch, n); \
+    convert_u8_double_scaled (c, min_val, max_val, min, max, \
+                              src, dst, src_pitch, dst_pitch, n); \
   }                                                               \
-  static long \
-  convert_double_ ## name (void *src, \
+  static void \
+  convert_double_ ## name (BablConversion *c, void *src, \
                            void *dst, \
                            int src_pitch, \
                            int dst_pitch, \
                            long n)                                 \
   { \
-    return convert_double_u8_scaled (min_val, max_val, min, max, \
-                                     src, dst, src_pitch, dst_pitch, n); \
+    convert_double_u8_scaled (c, min_val, max_val, min, max, \
+                              src, dst, src_pitch, dst_pitch, n); \
   }
 
 MAKE_CONVERSIONS (u8, 0.0, 1.0, 0x00, UINT8_MAX)
 MAKE_CONVERSIONS (u8_luma, 0.0, 1.0, 16, 235)
-MAKE_CONVERSIONS (u8_chroma, 0.0, 1.0, 16, 240)
+MAKE_CONVERSIONS (u8_chroma, -0.5, 0.5, 16, 240)
 
 void
 babl_base_type_u8 (void)
